-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************

---------------------------------------------------------------------------------
-- NOTE: the Central Data Warehouse (CDW) is always on DB2 so the staging  tables
-- and other DB objects are always the same whatever is the RIM database involved 
-- in the ETL process.
---------------------------------------------------------------------------------

--
-- We create a staging table for the data retrieved  from the  DM_METRICS  table; 
-- i.e. from the 1:1 join between DM_METRICS and TWG_DM_METRICS tables located at 
-- RIM database. When migrating data from the RIM database to the CDW database we 
-- introduce a new INTEGER sequence, in place of the RAW one used  at the RIM DB,
-- to enumerate the newly added records and to control future ETLs inside the CDW 
-- or other Data Mart Databases.
--
CREATE TABLE AMW.stage_dm_metrics_template (
  metric_id            BIGINT      NOT NULL,
  COLLECTION_DATE      DATE        NOT NULL,
  HOSTNAME             VARCHAR(32) NOT NULL,
  ENDPOINT             VARCHAR(32) NOT NULL,
  PROFILE_COLLECTION   VARCHAR(64) NOT NULL,
  PROBE_COLLECTION     VARCHAR(32) NOT NULL,
  PROBE                VARCHAR(32) NOT NULL,
  PROBE_DESC           VARCHAR(64),
  PROBE_ARG            VARCHAR(32) NOT NULL,
  MIN_VALUE_00         FLOAT,
  MAX_VALUE_00         FLOAT,
  AVG_VALUE_00         FLOAT,
  MIN_VALUE_01         FLOAT, 
  MAX_VALUE_01         FLOAT, 
  AVG_VALUE_01         FLOAT, 
  MIN_VALUE_02         FLOAT, 
  MAX_VALUE_02         FLOAT, 
  AVG_VALUE_02         FLOAT, 
  MIN_VALUE_03         FLOAT, 
  MAX_VALUE_03         FLOAT, 
  AVG_VALUE_03         FLOAT, 
  MIN_VALUE_04         FLOAT, 
  MAX_VALUE_04         FLOAT, 
  AVG_VALUE_04         FLOAT, 
  MIN_VALUE_05         FLOAT, 
  MAX_VALUE_05         FLOAT, 
  AVG_VALUE_05         FLOAT, 
  MIN_VALUE_06         FLOAT, 
  MAX_VALUE_06         FLOAT, 
  AVG_VALUE_06         FLOAT, 
  MIN_VALUE_07         FLOAT, 
  MAX_VALUE_07         FLOAT, 
  AVG_VALUE_07         FLOAT, 
  MIN_VALUE_08         FLOAT, 
  MAX_VALUE_08         FLOAT, 
  AVG_VALUE_08         FLOAT, 
  MIN_VALUE_09         FLOAT, 
  MAX_VALUE_09         FLOAT, 
  AVG_VALUE_09         FLOAT, 
  MIN_VALUE_10         FLOAT, 
  MAX_VALUE_10         FLOAT, 
  AVG_VALUE_10         FLOAT, 
  MIN_VALUE_11         FLOAT, 
  MAX_VALUE_11         FLOAT, 
  AVG_VALUE_11         FLOAT, 
  MIN_VALUE_12         FLOAT, 
  MAX_VALUE_12         FLOAT, 
  AVG_VALUE_12         FLOAT, 
  MIN_VALUE_13         FLOAT, 
  MAX_VALUE_13         FLOAT, 
  AVG_VALUE_13         FLOAT, 
  MIN_VALUE_14         FLOAT, 
  MAX_VALUE_14         FLOAT, 
  AVG_VALUE_14         FLOAT, 
  MIN_VALUE_15         FLOAT, 
  MAX_VALUE_15         FLOAT, 
  AVG_VALUE_15         FLOAT, 
  MIN_VALUE_16         FLOAT, 
  MAX_VALUE_16         FLOAT, 
  AVG_VALUE_16         FLOAT, 
  MIN_VALUE_17         FLOAT, 
  MAX_VALUE_17         FLOAT, 
  AVG_VALUE_17         FLOAT, 
  MIN_VALUE_18         FLOAT, 
  MAX_VALUE_18         FLOAT, 
  AVG_VALUE_18         FLOAT, 
  MIN_VALUE_19         FLOAT, 
  MAX_VALUE_19         FLOAT, 
  AVG_VALUE_19         FLOAT, 
  MIN_VALUE_20         FLOAT, 
  MAX_VALUE_20         FLOAT, 
  AVG_VALUE_20         FLOAT, 
  MIN_VALUE_21         FLOAT, 
  MAX_VALUE_21         FLOAT, 
  AVG_VALUE_21         FLOAT, 
  MIN_VALUE_22         FLOAT, 
  MAX_VALUE_22         FLOAT, 
  AVG_VALUE_22         FLOAT, 
  MIN_VALUE_23         FLOAT, 
  MAX_VALUE_23         FLOAT, 
  AVG_VALUE_23         FLOAT, 
  MIN_DAILY_VALUE      FLOAT NOT NULL, 
  MAX_DAILY_VALUE      FLOAT NOT NULL, 
  AVG_DAILY_VALUE      FLOAT NOT NULL, 
  MIN_HOURLY_AVG       FLOAT NOT NULL,
  MAX_HOURLY_AVG       FLOAT NOT NULL,
  TWH_GMTOFFSET_MIN    INTEGER NOT NULL
);
CREATE TABLE AMW.stage_dm_metrics LIKE AMW.stage_dm_metrics_template;

--
-- This table has the same columns  as AMW.stage_dm_metrics table and is 
-- used to collect all the records discarded during the AMW.stage_dm_metrics 
-- data loading.
--
CREATE TABLE AMW.Invalid_Data LIKE AMW.stage_dm_metrics_template;

--
-- The AMW.stage_metrics_hour table provides a first step for data normalization
-- to best fit the  tables  available in  the TWG  schema. It  introduces also a
-- TIMESTAMP  field (insert_dttm) to store  the  insertion  DATE and TIME in UTC
-- format.
--
CREATE TABLE AMW.stage_metrics_hour (
  metric_id            BIGINT      NOT NULL,
  insert_dttm          TIMESTAMP   NOT NULL,
  COLLECTION_DATE      DATE        NOT NULL,
  COLLECTION_TIME      TIME        NOT NULL,
  HOSTNAME             VARCHAR(32) NOT NULL,
  ENDPOINT             VARCHAR(32) NOT NULL,
  PROFILE_COLLECTION   VARCHAR(64) NOT NULL,
  PROBE_COLLECTION     VARCHAR(32) NOT NULL,
  PROBE                VARCHAR(32) NOT NULL,
  PROBE_DESC           VARCHAR(64),
  PROBE_ARG            VARCHAR(32) NOT NULL,
  Msmt_Min_Val         FLOAT,
  Msmt_Max_Val         FLOAT,
  Msmt_Avg_Val         FLOAT,
  Msmt_Tot_Val         FLOAT,
  Msmt_Smpl_Cnt        FLOAT
);
CREATE TABLE AMW.stage_metrics_hour_copy LIKE AMW.stage_metrics_hour;

--
-- This table has the same columns of the TWG.Comp table and is used to 
-- determine the Comp_Typ_Cd by the mean of the AMW.CompTyp_Cd_Trig
--
CREATE TABLE AMW.stage_comp LIKE TWG.Comp;

-- we need an extended stage_comp table to pass also the information
-- used by the AMW.CompTyp_Cd_Trig to determine which OS is running on the
-- specific component.
--
ALTER TABLE AMW.stage_comp ADD COLUMN PROFILE_COLLECTION VARCHAR(64);

--
-- Lookup and reject tables for DM. We're using hostname as the lookup value
--
CREATE TABLE AMW.cust_lookup (
   cust_acct_cd  CHAR(3),
   value         CHAR(32)
);

CREATE TABLE AMW.centr_lookup (
   centr_cd  CHAR(3),
   value     CHAR(32)
);

--
-- //////////// create the AMW Metric Dimension staging Table
--
CREATE TABLE AMW.stage_d_metric (
  metric_id            INTEGER       NOT NULL,
  insert_dttm          TIMESTAMP     NOT NULL,
  met_name             VARCHAR(52)   NOT NULL,
  met_desc             VARCHAR(255),
  met_units            CHAR(20)      NOT NULL,
  met_category         CHAR(20)      NOT NULL,
  min_exists           CHARACTER     NOT NULL,
  max_exists           CHARACTER     NOT NULL,
  avg_exists           CHARACTER     NOT NULL,
  total_exists         CHARACTER     NOT NULL,
  msrc_nm              VARCHAR(50),
    PRIMARY KEY (metric_id)
);

--
-- //////////// create some support views used to perform the hostname decomposition
-- //////////// into network_domain, network_subdomain and eventually network_subdomain_2
--
create view AMW.hostname_v1 as 
select
  Comp_ID as host_id, 
  Comp_Nm as hostname,
  LOCATE('.',Comp_Nm) + 1 as name_b_beg,
  LOCATE('.',Comp_Nm,LOCATE('.',Comp_Nm) + 1) + 1 as name_c_beg,
  LOCATE('.',Comp_Nm,LOCATE('.',Comp_Nm,LOCATE('.',Comp_Nm) + 1) + 1) + 1 as name_d_beg,
  LOCATE('.',Comp_Nm,LOCATE('.',Comp_Nm,LOCATE('.',Comp_Nm,LOCATE('.',Comp_Nm) + 1) + 1) + 1) + 1 as name_e_beg
from
  TWG.Comp
where Comp_Ds <> 'AMW_DATA'
group by
  Comp_ID, Comp_Nm
;

create view AMW.hostname_v2 as
select
  host_id,
  hostname,
  name_b_beg,
  name_c_beg,
  name_d_beg,
  name_e_beg,
  case when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg > 1) then 5
       when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg > 1 and name_e_beg = 1) then 4
       when (name_b_beg > 1 and name_c_beg > 1 and name_d_beg = 1 ) then 3
       when (name_b_beg > 1 and name_c_beg = 1 ) then 2
       when (name_b_beg = 1 ) then 1
  end  as name_parts
from
  AMW.hostname_v1
;

create view AMW.hostname_decomp as
select
  host_id,      
  hostname,   
  CASE 
    when name_parts = 5 then substr(hostname,name_d_beg)        
    when name_parts = 4 then substr(hostname,name_c_beg)        
    when name_parts = 3 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as network_domain,   
  CASE 
    when name_parts = 5 then substr(hostname,name_c_beg)        
    when name_parts = 4 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as network_subdomain,   
  CASE 
    when name_parts = 5 then substr(hostname,name_b_beg)        
    else 'no value'   
  END as network_subdomain_2,   
  CASE 
    when hostname is null THEN null        
    when name_b_beg > 1 THEN SUBSTR(hostname, 1, name_b_beg - 2)        
    else hostname         
  END as short_hostname
from  AMW.hostname_v2
;



