-- *****************************************************************************
-- *
-- * Licensed Materials - Property of IBM
-- * 5724-C40
-- * (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- *		
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with
-- * IBM Corp.
-- *
-- *****************************************************************************

-----------------------------------------------------------------
------------------------ DIMENSION TABLES -----------------------
-----------------------------------------------------------------

--
-- /////////////// Metric Dimension Table: stores a single piece of descriptive information used
-- /////////////// to identify fact atble records; for AMW dimensions are all the monitors defined 
-- /////////////// for the metric categories: CPU, Memory, Network interface, I/O, File system
-- /////////////// and collected under the DM2 Measurement Group.
--
-- /////////////// NOTE: the name of this kind of table must begin with D_ and end in METRIC, e.g.
-- /////////////// D_x_METRIC, where x is optional and represents the metric group description.
--
CREATE TABLE AMW.D_DM2_METRIC (
  metric_id            INTEGER       NOT NULL,
  met_name             VARCHAR(52)   NOT NULL,
  met_desc             VARCHAR(255),
  met_units            CHAR(20)      NOT NULL,
  met_category         CHAR(20)      NOT NULL,
  min_exists           CHARACTER     NOT NULL,
  max_exists           CHARACTER     NOT NULL,
  avg_exists           CHARACTER     NOT NULL,
  total_exists         CHARACTER     NOT NULL,
  msrc_nm              VARCHAR(50),
    PRIMARY KEY (metric_id)
);

--
-- /////////////// Component Dimension Table: stores component attributes (column name = component attribute)
-- /////////////// that are displayed in the report interface so that users can filter on them; for AMW it 
-- /////////////// contains the hostname (fyully qualifyed or not) and the information about the OS running 
-- /////////////// on it.
--
-- /////////////// NOTE: the name of this kind of table must begin with D_ and must NOT end in METRIC
--
create table AMW.D_HOST (
  host_id             INTEGER      NOT NULL,
  host_start_dttm     TIMESTAMP    NOT NULL,
  host_end_dttm       TIMESTAMP    NOT NULL,
  hostname            VARCHAR(64)  NOT NULL,
  os_name             VARCHAR(120) NOT NULL,
  network_domain      VARCHAR(120) NOT NULL,
  network_subdomain   VARCHAR(120) NOT NULL,
  network_subdomain_2 VARCHAR(120) NOT NULL,
  short_hostname      VARCHAR(120) NOT NULL,
    PRIMARY KEY (host_id)
);

-----------------------------------------------------------------
-------------------------- FACT TABLES --------------------------
-----------------------------------------------------------------

--
-- /////////////// Fact Table: contains measurement informations and its columns must include the following:
-- ///////////////
-- /////////////// - FK to the Component Dimension Table;
-- /////////////// - metric_id: single integer key into the D_x_METRIC table;
-- /////////////// - meas_date: should represent the start of the week, day or month;
-- /////////////// - meas_hour: contains summarized timestamps or hourly boundaries 
-- ///////////////              (it's only required for F_x_HOUR tables);
-- /////////////// - min_value, max_value, avg_value, total_value, sample_count: 
-- ///////////////              are only required if they are referred in the metric table.
--
-- /////////////// NOTE: the name of this kind of table must begin with F_ and must end with a period
-- /////////////// such as HOUR, DAY, WEEK, MONTH, e.g. F_x_DAY, where x is optional and is used to
-- /////////////// distinguish one fact table from another in the same data mart.
--
CREATE TABLE AMW.F_DAY (
  host_id     INTEGER,
  metric_id   INTEGER,
  meas_date   TIMESTAMP,
  min_value   DECIMAL(18,2),
  max_value   DECIMAL(18,2),
  avg_value   DECIMAL(18,2)
);


