-- ############################################################################
-- #
-- #  Licensed Materials - Property of IBM
-- #  Product ID = 5724-C04
-- #
-- #  (C) Copyright IBM Corp. 2002.  All Rights Reserved.
-- #
-- #  US Government Users Restricted Rights - Use, duplication or
-- #  disclosure restricted by GSA ADP Schedule Contract with
-- #  IBM Corp.
-- #
-- #  File Information: Common/src/tedw_app/amx/pkg/v511/cdw/ddl/amx_cdw_schema.sql, tmnt_etl, tmnt_5.1.1, DM020906B
-- #  Revision: 1.3
-- #  Date: 9/3/02 10:25:20
-- ############################################################################

---------------------------------------
-- /////////// Prune Tables ///////////
---------------------------------------

CREATE TABLE AMX.prune_control (
  age_days   integer,
  prune_key  integer )
;

CREATE TABLE AMX.prune_log (
  prune_action_dttm  timestamp,
  age_days           integer,
  prune_key          integer,
  prune_before_dttm  timestamp )
;

------------------------------
-- // ITM CONVERSION TABLES //
------------------------------

-- This table is used to support  any product that
-- may have created multiples categories for the same product 
-- such as ITM Operating System Resource models
-- we convert all the categories to a unique category_convert

CREATE TABLE AMX.Categories_Convert (
  Category_Convert  varchar(128) not null,
  Category          varchar(128) not null,
  Description       varchar(128),
    primary key (Category, Category_Convert)
);

-- This table is used to support any product that
-- may have created multiples ITM keys for the same component type 
-- such as ITM Operating System Resource models
-- we convert all the key_typ to a unique key_typ_convert 

CREATE TABLE AMX.Inst_Key_Convert (
  Key_Typ_Convert  varchar(254) not null,
  Key_Typ          varchar(254) not null,
  Description      varchar(128),
    primary key (Key_Typ_Convert, Key_Typ)
);

-- This table is used to support any product that
-- needs to convert multiple resource names to one 
-- unique name, which is used to map a TEDW CompTyp
-- by the AMX.Resource_Transl table...

create table AMX.Resources_Convert (
  Resource_Convert  varchar(128) not null,
  Resource          varchar(128) not null,
  Description       varchar(128),
    primary key (Resource_Convert, Resource)
);

--------------------------------------------------
-- /// Translation Tables Between ITM and TEDW ///
--------------------------------------------------

CREATE TABLE AMX.RelnRul_Transl (
  CompTyp_Source_Cd  varchar(17) not null,
  CompTyp_Target_Cd  varchar(17) not null,
  RelnTyp_Cd         char(6) not null,
  RelnRul_Strt_DtTm  timestamp not null,
  RelnRul_End_DtTm   timestamp not null,
    PRIMARY KEY (CompTyp_Source_Cd, CompTyp_Target_Cd, 
                 RelnTyp_Cd, RelnRul_Strt_DtTm )
);

CREATE TABLE AMX.Resource_Transl (
  Resource    varchar(128) not null,
  CompTyp_Cd  varchar(17) not null,
    PRIMARY KEY (CompTyp_Cd)
);

CREATE TABLE AMX.Category_Transl (
  Category  varchar(128) not null,
  MSrc_Cd   char(3) not null,
    PRIMARY KEY (Msrc_Cd)
);

CREATE TABLE AMX.CompTyp_Transl (
  MSrc_Cd           char(3) not null,
  ITM_Key_Property  varchar(1096) not null,
  CompTyp_Cd        varchar(17) not null,
  Comp_Format_Nm    varchar(254) not null,
    PRIMARY KEY (MSrc_Cd, CompTyp_Cd)
);

CREATE TABLE AMX.AttrTyp_Transl (
  MSrc_Cd            char(3) not null,
  ITM_Attr_Property  varchar(254) not null,
  AttrTyp_Cd         varchar(17) not null,
    PRIMARY KEY (MSrc_Cd, ITM_Attr_Property, AttrTyp_Cd)
);

ALTER TABLE AMX.Category_Transl
  ADD CONSTRAINT FKCat_T_MSrc
  FOREIGN KEY (MSrc_Cd)
  REFERENCES TWG.MSrc;

ALTER TABLE AMX.CompTyp_Transl
  ADD CONSTRAINT FKCompTyp_T_Cat_T
  FOREIGN KEY (MSrc_Cd)
  REFERENCES AMX.Category_Transl;
 
ALTER TABLE AMX.AttrTyp_Transl
  ADD CONSTRAINT FKAttrTyp_T_Cat_T
  FOREIGN KEY (MSrc_Cd)
  REFERENCES AMX.Category_Transl;
  
--
-- Table that only contains properties that are not attributes
--
CREATE TABLE AMX.Stage_CompTyp2_Transl (
  MSrc_Cd     char(3),
  Long_Name   varchar(254),
  CompTyp_Cd  varchar(17),
  Comp_Nm     varchar(254)
);

-----------------------------------------------------
--/////// STAGING ITM TABLES AFTER EXTRACTION ///////
-----------------------------------------------------


-- ///////////////////
-- ///////// Resources
-- ///////////////////
create table AMX.stage1_resources (
  resource  varchar(128),
  context   varchar(64),
  rcid      bigint not null,
  id        bigint not null,
  eid	     integer not null,	
    primary key (rcid, eid)
);

-- ///////////////////
-- //////// Instances
-- ///////////////////
create table AMX.stage1_instances (
  instance_key  varchar(2096),
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
    primary key (iid,eid)
);


-- ///////////////////
-- /////// MetricsData
-- ///////////////////
create table AMX.stage_metricsdata ( 
  mid           bigint not null,
  metricvalue   float not null,
  timekey_dttm  timestamp not null,
  iid           bigint not null,
  eid           integer not null,
    primary key (mid, timekey_dttm, iid, eid)
);

-- ///////////////////
-- //////// Categories
-- ///////////////////
create table AMX.Stage1_categories (
  name  varchar(254),
  rcid  bigint not null,
  cid   bigint not null,
  eid   integer not null,
    primary key (cid,eid)
);

-- ///////////////////
-- //// CategoriesData
-- ///////////////////
create table AMX.stage_categoriesdata (
  cid            bigint not null,
  categoryvalue  varchar(128),
  timekey_dttm   timestamp not null,
  iid            bigint not null,
  eid            integer not null,
    primary key (cid,timekey_dttm,iid,eid)
);

-- ///////////////////
-- ///////// Endpoints
-- ///////////////////
create table AMX.stage_endpoints (
  eid             integer not null,
  host_nm         varchar(120),
  ip_addr         varchar(20),
  endpoint_label  varchar(64),
  GMT_offset      integer not null,
    primary key (eid)
);

-----------------------------------------------------
-- /////// STAGING ITM TABLES RECONSTITUTED /////////
-----------------------------------------------------

-- ///////////////////
-- //////// RmProfiles
-- ///////////////////
create table AMX.stage_rmprofiles (
  category       varchar(128),
  profile        varchar(256),
  resource_model varchar(128),
  id             bigint not null,
  eid            integer not null,
    primary key (id,eid)
);

-- ///////////////////
-- ///////// Resources
-- ///////////////////
create table AMX.stage_resources (
  resource  varchar(128),
  context   varchar(64),
  rcid      bigint not null,
  id        bigint not null,
  eid       integer not null,	
    primary key (rcid, eid)
);

-- ///////////////////
-- ///////// Instances
-- ///////////////////
create table AMX.stage_instances (
  instance_key  varchar(2096),
  iid           bigint not null,
  rcid          bigint not null,
  eid           integer not null,
    primary key (iid,eid)
);

-- ///////////////////
-- /////////// Metrics
-- ///////////////////
create table AMX.stage_metrics (
  name  varchar(128),
  rcid  bigint not null,
  mid   bigint not null,
  stat  varchar(8),
  eid   integer not null,
    primary key (mid,eid)
);

-- ///////////////////
-- //////// Categories
-- ///////////////////
create table AMX.stage_categories (
  name  varchar(254),
  rcid  bigint not null,
  cid   bigint not null,
  eid   integer not null,
    primary key (cid,eid)
);

-------------------------------------------
-- /////////// EXCEPTION TABLES ///////////
-------------------------------------------

CREATE TABLE AMX.Stage_CompTyp_Transl_Ex (
  CompTyp_Cd  varchar(17),
  MSrc_Cd     char(3),
  Error_Msg   varchar(254),
  Timestamp   timestamp
);

CREATE TABLE AMX.Stage_Resource_Transl_Ex (
  Resource    varchar(128),
  CompTyp_Cd  varchar(17),
  Error_Msg   varchar(254),
  Timestamp   timestamp
);

CREATE TABLE AMX.Stage_RelnRul_Transl_Ex (
  CompTyp_Source_Cd  varchar(17) not null,
  CompTyp_Target_Cd  varchar(17) not null,
  RelnTyp_Cd         char(6) not null,
  RelnRul_Strt_DtTm  timestamp not null,
  RelnRul_End_DtTm   timestamp not null,
  Error_Msg          varchar(254),
  Timestamp          timestamp
);

CREATE TABLE AMX.Stage_AttrTyp_Transl_Ex (
  CompTyp_Cd  varchar(17),
  MSrc_Cd     char(3),
  Error_Msg   varchar(254),
  Timestamp   timestamp
);

CREATE TABLE AMX.Stage_RmProfiles_Ex (
  Category       varchar(128),
  Profile        varchar(256),
  Resource_Model varchar(128),
  ID             bigint not null,
  EID            integer not null,
  Error_Msg      varchar(254),
  Timestamp      timestamp not null
);

CREATE TABLE AMX.Stage_Inst_Comp_PAC_Ex (
  PAC         char(3),
  Property    varchar(254),
  IID         bigint,
  EID         integer,
  RCID        bigint,
  CompTyp_Cd  varchar(17),
  Error_Msg   varchar(254),
  Timestamp   timestamp not null
);

CREATE TABLE AMX.Stage_Metrics_Ex (
  PAC        char(3),
  Name       varchar(128),
  RCID       bigint,
  MID        bigint,
  Stat       varchar(8),
  EID        integer,
  Error_Msg  varchar(254),
  Timestamp  timestamp not null
); 

CREATE TABLE AMX.Stage_Categories_Ex (
  CompTyp_Cd  varchar(17),
  PAC         char(3),
  Name        varchar(254),
  RCID        bigint,
  CID         bigint,
  EID         integer,
  Error_Msg   varchar(254),
  Timestamp   timestamp not null
); 

------------------------------------------------------------
-- Source tables with no errors and with the TEDW CompTyp_Cd 
------------------------------------------------------------

CREATE TABLE AMX.Stage_InstKey_No_Ex (
 ITM_KEY       VARCHAR(254) NOT NULL,
 PROPERTY_VAL  VARCHAR(254) NOT NULL,
 IID           BIGINT       NOT NULL,
 EID           INTEGER      NOT NULL,
 RCID          BIGINT       NOT NULL,
 COMPTYP_CD    VARCHAR(17)  NOT NULL,
   PRIMARY KEY (IID, EID, RCID, PROPERTY_VAL, COMPTYP_CD, ITM_KEY)
);
 
CREATE TABLE AMX.Stage_Ep_No_Ex (
  EID            integer not null,
  Host_Nm        varchar(120),
  Ip_Addr        varchar(20),
  Endpoint_Label varchar(64),
  GMT_Offset     integer not null,
    primary key(eid)
); 

CREATE TABLE AMX.Stage_RmProf_No_Ex (
  Category       varchar(128),
  Profile        varchar(256),
  Resource_Model varchar(128),
  ID      	     bigint not null,
  EID		         integer not null,
    primary key (id,eid)
);

CREATE TABLE AMX.Stage_Msmt_No_Ex (
  MsmtTyp_Nm   varchar(254) not null,
  Msmt_Val     float not null,
  Timekey_DtTm timestamp not null,
  IID          bigint not null,
  RCID         bigint not null,
  EID          integer not null
);
 

CREATE TABLE AMX.Stage_Attr_No_Ex (
 COMPTYP_CD    VARCHAR(17)  NOT NULL,
 ATTRTYP_CD    VARCHAR(17)  NOT NULL,
 ATTR_ITM      VARCHAR(254) NOT NULL,
 ATTR_VAL      VARCHAR(254),
 TIMEKEY_DTTM  TIMESTAMP    NOT NULL,
 IID           BIGINT       NOT NULL,
 RCID          BIGINT       NOT NULL,
 EID           INTEGER      NOT NULL,
   PRIMARY KEY (ATTRTYP_CD, ATTR_ITM, TIMEKEY_DTTM, IID, RCID, EID)
);


------------------------------
-- Tables used by:
--  - the parsing process
--  - the exception process
--  - the comp process
------------------------------

CREATE TABLE AMX.Stage_All_PACs_RelnRul (
  MSrc_Cd  char(3)     not null,
  pkey     varchar(17) not null,
  ckey     varchar(17) not null,
    primary key(pkey,ckey) 
);

CREATE UNIQUE INDEX AMX.RelnRul_x1 on AMX.Stage_All_PACs_RelnRul (ckey, pkey);

CREATE TABLE AMX.Stage_All_Comps_Exp (
  MSrc_Cd  char(3)     not null,
  ckey     varchar(17) not null,
  pkey     varchar(17) not null,
  lvl      smallint    not null,
    primary key(pkey,ckey) 
);

CREATE UNIQUE INDEX AMX.exp_x1 on AMX.Stage_All_Comps_exp (ckey, pkey);

CREATE TABLE AMX.Stage_Meta_Keys (
  CompTyp_Cd  varchar(17)  not null,
  ITM_Key     varchar(254) not null,
  lvl         smallint     not null,
  MSrc_Cd     char(3)      not null
);

CREATE TABLE AMX.Stage_Comp_Level (
  CompTyp_Cd  varchar(17),
  MSrc_Cd     char(3),
  lvl         integer
);

CREATE TABLE AMX.Temp_To_IntSeq (
  extctl_to_intseq  integer) 
;

CREATE TABLE AMX.Stage_Meta_Names (
  CompTyp_Cd  varchar(17)  not null,
  ITM_Name    varchar(254) not null,
  lvl         smallint     not null,
  MSrc_Cd     char(3)      not null
);	

-----------------------------------------------
-- ////// Instances table after parsing ///////
-----------------------------------------------

CREATE TABLE AMX.Stage_Key_Parsed (
  key_typ   varchar(254),
  key_val   varchar(254),
  position  integer,
  IID       bigint,
  EID       integer,
  RCID      bigint
);

-----------------------------------------------
-- /////////////// Lookup Tables //////////////
-----------------------------------------------

CREATE TABLE AMX.Cust_Lookup (
  Cust_Acct_Cd  char(10),
  Value         varchar(254)
);

CREATE TABLE AMX.Centr_Lookup (
  Centr_Cd  char(6),
  Value     varchar(254)
);

---------------------------------------------------
-- Metadata Copy tables:
-- These tables are used to see if the metadata has 
-- changed since the last run of the exception step
---------------------------------------------------

CREATE TABLE AMX.Stage_MData_Change (
  TABLE_NM  varchar(40),
  NUM_ROWS  integer
);

CREATE TABLE AMX.Stage_MSrc_Old (
  MSrc_Cd         char(6) not null,
  MSrc_Parent_Cd  char(6),
  MSrc_Nm         varchar(120) not null,
   CONSTRAINT XPKMSrc 
     PRIMARY KEY (MSrc_Cd)
);

CREATE TABLE AMX.Stage_Comp_Level_Old (
  CompTyp_Cd  varchar(17),
  MSrc_Cd     char(3),
  lvl         integer
);

CREATE TABLE AMX.Stage_Meta_Keys_Old (
  CompTyp_Cd varchar(17) not null,
  ITM_Key    varchar(254) not null,
  lvl        smallint not null,
  MSrc_Cd    char(3) not null
);

CREATE TABLE AMX.Stage_Meta_Names_Old (
  CompTyp_Cd  varchar(17) not null ,
  ITM_Name    varchar(254) not null,
  lvl         smallint not null ,
  MSrc_Cd     char(3) not null
);

CREATE TABLE AMX.Stage_CompTyp_Old (
  CompTyp_Cd         char(17) not null,
  CompTyp_Parent_Cd  char(17),
  CompTyp_Nm         varchar(120) not null,
  CompTyp_Strt_DtTm  timestamp not null,
  CompTyp_End_DtTm   timestamp not null,
   CONSTRAINT XPKCompTyp 
    PRIMARY KEY (CompTyp_Cd)
);

CREATE TABLE AMX.Stage_AttrRul_Old (
  CompTyp_Cd         char(17) not null,
  AttrTyp_Cd         char(17) not null,
  AttrRul_Strt_DtTm  timestamp not null,
  AttrRul_End_DtTm   timestamp not null,
  AttrRul_Dom_Ind    char not null,
   CONSTRAINT XPKAttrRul 
    PRIMARY KEY (CompTyp_Cd, AttrTyp_Cd)
);

CREATE TABLE AMX.Stage_RelnRul_Transl_Old (
  CompTyp_Source_Cd  varchar(17) not null,
  CompTyp_Target_Cd  varchar(17) not null,
  RelnTyp_Cd         char(6) not null,
  RelnRul_Strt_DtTm  timestamp not null,
  RelnRul_End_DtTm   timestamp not null,
    PRIMARY KEY (CompTyp_Source_Cd, CompTyp_Target_Cd, 
                 RelnTyp_Cd, RelnRul_Strt_DtTm )
);

CREATE TABLE AMX.Stage_All_Comps_Exp_Old (
  MSrc_Cd  char(3) not null,
  ckey     varchar(17) not null,
  pkey     varchar(17) not null,
  lvl      smallint not null,
    PRIMARY KEY (pkey, ckey) 
);

CREATE TABLE AMX.Stage_Wep_Installed_Old (
  msrc_cd     char(3)
);
